#ifndef DEAUTH_H
#define DEAUTH_H

#include <Arduino.h>
#include <ESP8266WiFi.h> // For MAC address type
#include "ui.h"          // For ButtonPressType
#include "scanner.h" // Include for StationInfo, frame_control_t etc.

// --- Deauth Module States ---
enum class DeauthStateType {
    SELECT_AP,      // Show list of APs from scanner
    SELECT_STA,      // Show list of STAs for selected AP (and Broadcast option)
    ATTACKING       // Sending deauth packets
};

// --- Constants ---
#define DEAUTH_PACKET_INTERVAL 50 // ms between sending packets
#define MAX_STAS_PER_AP 15       // Max stations to display for a selected AP
//#define BROADCAST_MAC {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF} // Define in .cpp instead
extern const uint8_t broadcast_mac[6]; // <<< ADD extern declaration

// --- Target Information ---
extern uint8_t deauth_target_ap_bssid[6];
extern uint8_t deauth_target_sta_mac[6];
extern char deauth_target_ap_ssid[33]; // Store SSID for display
extern bool deauth_attack_active;
extern uint8_t current_attack_mode; // <<< ADD extern declaration for UI access

// --- Function Declarations ---
void deauth_init();
void deauth_update();
void deauth_stop();
void deauth_draw(); // Function to draw deauth UI based on state
void deauth_handle_input(ButtonPressType pressType); // Handle button presses

// Internal functions
void send_deauth_packet(const uint8_t* ap_bssid, const uint8_t* sta_mac, uint8_t channel);

// SDK function for packet injection
extern "C" {
    #include "user_interface.h"
    // Function to send raw 802.11 frames (check SDK docs for exact signature/availability)
    // int wifi_send_pkt_freedom(uint8 *buf, int len, bool sys_seq); // Example signature
    // Let's assume this is the correct one for now. If compilation fails, we'll find the right one.
    int wifi_send_pkt_freedom(uint8_t *buf, int len, bool sys_seq);
    // Function to set fixed WiFi rate
    int wifi_set_user_fixed_rate(uint8_t enable_mask, uint8_t rate);
    // Function to set max TX power (already declared in .cpp, but good practice here too)
    void system_phy_set_max_tpw(uint8 max_tpw);
}

#endif // DEAUTH_H 