#ifndef UI_H
#define UI_H

#include <Arduino.h>
#include <U8g2lib.h> // Include U8g2 library
#include "config.h"  // For button pin, etc.

// --- UI State Enum ---
enum class UIState {
    MAIN_MENU,
    SCANNER_MODE,
    DEAUTH_MODE,
    BEACON_MODE,
    MITM_MODE,
    ROGUE_AP_MODE
    // Add other states as needed
};

// --- Button States ---
enum class ButtonPressType {
    NO_PRESS,
    SHORT_PRESS,
    LONG_PRESS
};

// --- Global UI Variables (defined in ui.cpp) ---
extern U8G2_SSD1306_128X64_NONAME_F_HW_I2C oled; // Make OLED object accessible
extern UIState currentState;       // <<< Make sure this is extern
extern int currentMenuIndex;       // <<< Make sure this is extern
extern bool needsRedraw;           // <<< Make sure this is extern
extern const char *mainMenuItems[]; // Declare main menu items array
extern const int mainMenuLength;    // Declare main menu length

// --- Function Declarations ---

// Initialization
void ui_init();

// Main update loop for UI (handles button presses, updates display)
void ui_update();

// Drawing functions
void ui_draw_header(const char* title);
void ui_draw_battery(int x, int y, int percentage);
void ui_draw_main_menu();
// Add drawing functions for each mode/state later

// Getters
UIState ui_get_current_state();
int ui_get_menu_index();

// Button Function Declarations
void button_update();
ButtonPressType button_get_press();

void handle_button();    // <<< DECLARE button handling function
void draw_ui();          // <<< DECLARE main UI drawing function

#endif // UI_H 