#include "utils.h"
#include "config.h"

// --- Battery ---
float readBatteryVoltage() {
    int raw = analogRead(BATTERY_PIN);
    float voltage = raw * (VOLTAGE_MAX / 1024.0);
    return voltage;
}

int estimateBatteryPercentage(float voltage) {
    int percentage = map(voltage * 100, VOLTAGE_MIN * 100, VOLTAGE_MAX * 100, 0, 100);
    if (percentage < 0) percentage = 0;
    if (percentage > 100) percentage = 100;
    return percentage;
}

// --- MAC Address Formatting ---
String macToString(const uint8_t* mac) {
    char buf[18];
    snprintf(buf, sizeof(buf), "%02X:%02X:%02X:%02X:%02X:%02X",
             mac[0], mac[1], mac[2], mac[3], mac[4], mac[5]);
    return String(buf);
}

bool stringToMac(const String& macStr, uint8_t* mac) {
    if (macStr.length() != 17) return false;
    int byteNum = 0;
    for (int i = 0; i < 17; i += 3) {
        if (byteNum >= 6) return false;
        String byteStr = macStr.substring(i, i + 2);
        char* endPtr;
        mac[byteNum] = strtol(byteStr.c_str(), &endPtr, 16);
        if (*endPtr != '\0') return false;
        byteNum++;
    }
    return byteNum == 6;
}

// --- Other Helpers ---
void printHex(uint8_t* data, size_t len) {
    for (size_t i = 0; i < len; i++) {
        if (data[i] < 0x10) Serial.print("0");
        Serial.print(data[i], HEX);
        Serial.print(" ");
    }
    Serial.println();
} 